==> kelvin_sdk-7.0.1-py3-none-any.whl: kelvin/sdk/server/interface/node.py <==
"""
Copyright 2021 Kelvin Inc.

Licensed under the Kelvin Inc. Developer SDK License Agreement (the "License"); you may not use
this file except in compliance with the License.  You may obtain a copy of the
License at

http://www.kelvininc.com/developer-sdk-license

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
WARRANTIES OF ANY KIND, either express or implied.  See the License for the
specific language governing permissions and limitations under the License.
"""
from typing import Optional

from kelvin.sdk.lib.models.operation import OperationResponse
from kelvin.sdk.lib.models.types import StatusDataSource
from kelvin.sdk.server.models.router import KelvinSDKServerRouter

router = KelvinSDKServerRouter(
    prefix="/nodes",
    tags=["Nodes - [kelvin node]"],
    responses={404: {"description": "Not found"}},
)


@router.get("")
def node_list(query: Optional[str] = None, source: StatusDataSource = StatusDataSource.CACHE) -> OperationResponse:
    """
    Returns the list of nodes available on the platform.
    """
    if query:
        from kelvin.sdk.interface import node_search as _node_search

        return _node_search(query=query, source=source, should_display=False)
    else:
        from kelvin.sdk.interface import node_list as _node_list

        return _node_list(source=source, should_display=False)


@router.get("/provision_script")
def node_provision_script() -> OperationResponse:
    """
    Get the provisioning script to setup a node.
    """
    from kelvin.sdk.interface import node_provision_script as _node_provision_script

    return _node_provision_script()


@router.get("/{node_name}")
def node_show(node_name: str, source: StatusDataSource = StatusDataSource.CACHE) -> OperationResponse:
    """
    Displays all the details of the specified node from the platform.
    """
    from kelvin.sdk.interface import node_show as _node_show

    return _node_show(node_name=node_name, source=source, should_display=False)

==> kelvin_sdk-7.8.1-py3-none-any.whl: kelvin/sdk/server/interface/node.py <==
"""
Copyright 2021 Kelvin Inc.

Licensed under the Kelvin Inc. Developer SDK License Agreement (the "License"); you may not use
this file except in compliance with the License.  You may obtain a copy of the
License at

http://www.kelvininc.com/developer-sdk-license

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
WARRANTIES OF ANY KIND, either express or implied.  See the License for the
specific language governing permissions and limitations under the License.
"""
from typing import Optional

from kelvin.sdk.lib.models.operation import OperationResponse
from kelvin.sdk.lib.models.types import StatusDataSource
from kelvin.sdk.server.models.router import KelvinSDKServerRouter

router = KelvinSDKServerRouter(
    prefix="/nodes",
    tags=["Nodes - [kelvin node]"],
    responses={404: {"description": "Not found"}},
)


@router.get("")
def node_list(query: Optional[str] = None) -> OperationResponse:
    """
    Returns the list of nodes available on the platform.
    """
    if query:
        from kelvin.sdk.interface import node_search as _node_search

        return _node_search(query=query, should_display=False)
    else:
        from kelvin.sdk.interface import node_list as _node_list

        return _node_list(should_display=False)


@router.get("/provision_script")
def node_provision_script() -> OperationResponse:
    """
    Get the provisioning script to setup a node.
    """
    from kelvin.sdk.interface import node_provision_script as _node_provision_script

    return _node_provision_script()


@router.get("/{node_name}")
def node_show(node_name: str, source: StatusDataSource = StatusDataSource.CACHE) -> OperationResponse:
    """
    Displays all the details of the specified node from the platform.
    """
    from kelvin.sdk.interface import node_show as _node_show

    return _node_show(node_name=node_name, source=source, should_display=False)
